########################################################
##    ZCybermut - Ease the access to Cybermut payment system
##    Cybermut.py - Main object file
##
##  Copyright (C) 2001+  IngeniWeb SARL (http://www.ingeniweb.com)
##
##    This software is copyrighted by IngeniWeb SARL. 
##    This software is protected by LGPL licence.
##    See LICENCE.txt
##
##    See README.txt for documentation
##
##  FileName : $RCSfile: Cybermut.py,v $
##  Revision : $Revision: 1.3 $)
##  Author : $Author: odeckmyn $
##  Version tag name (if any) : $Name:  $
########################################################

from AccessControl import ClassSecurityInfo
from Globals import InitializeClass 
from Acquisition import Implicit
from Globals import Persistent
from AccessControl.Role import RoleManager
from OFS.SimpleItem import Item
from Globals import HTML, HTMLFile, DTMLFile, MessageDialog
from OFS.PropertyManager import PropertyManager

from Products.PythonScripts.standard import special_formats

import os
import string

import libcybermut

## Helper functions

def isoLang2CybermutLang(lang):
    """isoLang2CybermutLang(lang) -> string

       Returns Cybermut language code ('francais' or 'anglais' or 'allemand' or 'espagnol' or 'italien') 
       given iso lang code ('fr', 'en', 'de', 'es', 'it', etc...).
       If iso code is not known, return "en" code (english)."""
    lang=string.lower(lang)
    if lang in ('fr', 'be', 'ca'):
        return 'francais'
    elif lang in ('de', ):
        return 'allemand'
    elif lang in ('es', ):
        return 'espagnol'
    elif lang in ('it', ):
        return 'italien'
    else:
        return 'anglais'

## Cybermut main class


Cybermut_addForm = DTMLFile('dtml/addForm', globals())

def Cybermut_add(self, id, REQUEST = {}):
    """Add Cybermut Product"""
    p = Cybermut(id)
    self._setObject(id, p)
    if REQUEST.has_key('RESPONSE'):
        return self.manage_main(self, REQUEST)
    else:
        return getattr(self, id)

class Cybermut(Implicit, Persistent, RoleManager, PropertyManager, Item):
	"""Cybermut Product Main Class"""

	meta_type="Cybermut"

	security=ClassSecurityInfo()

	_properties=(
            {'id':   'url_banque',
	     'type': 'string',
	     'mode': 'w'},
            
	    {'id':   'version',
	     'type': 'string',
	     'mode': 'w'},

	    {'id':   'key_name',
	     'type': 'string',
	     'mode': 'w'},

	    {'id':   'url_retour',
	     'type': 'string',
	     'mode': 'w'},

	    {'id':   'url_retour_ok',
	     'type': 'string',
	     'mode': 'w'},

	    {'id':   'url_retour_err',
	     'type': 'string',
	     'mode': 'w'},

	    {'id':   'code_societe',
	     'type': 'string',
	     'mode': 'w'},

	)

	manage_options = PropertyManager.manage_options + Item.manage_options + RoleManager.manage_options + (
	    {'label': 'ReadMe / HowTo', 'action': 'manage_ReadMe'},
	   )
	

	def __init__(self, id, url_banque='https://www.creditmutuel.fr/telepaiement/test/paiement.cgi', version='1.2', key_name="",  
	             url_retour='', url_retour_ok='', url_retour_err='', code_societe=''):
		"""Constructor"""
		self.id=id
		self.url_banque=url_banque
		self.version=version
		self.key_name=key_name
		self.url_retour=url_retour
		self.url_retour_ok=url_retour_ok
		self.url_retour_err=url_retour_err
                self.code_societe=code_societe

	def physical_location(self, name="ZCybermut"):
    		app=self.getPhysicalRoot()
    		p=getattr(app.Control_Panel.Products, name, None)
    		if p:
        		return p.home
    		raise '%s not found in Control_Panel/Products' % (name, )


	security.declarePublic('manage_ReadMe')
	def manage_ReadMe(self):
		"""ReadMe File"""
		readme=open(os.path.join(self.physical_location(),"README.txt")).read()
                readme=special_formats['structured-text'](readme)
		return self.manage_page_header()+self.manage_tabs()+readme+self.manage_page_footer()

	def getKeyFullPath(self, filename):
	        """Given only the filename of the cybermut key, will return the full path needed
		by cybermut library. """
		result=os.path.join(self.physical_location(),'keys',filename)
		if os.path.isfile(result):
			return result
		else:
			raise "Could not file key file %s (%s)"%(filename, result)
		 
	security.declarePublic('__call__')
	def __call__(self, montant, reference, texte_libre='', texte_bouton='Cybermut', langue='en', devise='EUR'):
		"""This is the main function. It builds the HTML Form for Cybermut system. 
                 reference (string) : unique product reference (width 12 max),
                 montant (float) : amount of product,
                 currency (string, optional) : iso code of currency (FRF,CHF,GBP,USD,EUR). Default is EUR
                 lang (string, optional) : language to use on Cybermut pages. French is default.
		 texte_libre (string, optional) : used to store a brief summary of order
                 
		See test() for example usage."""

		montant='%2.2f'%float(montant) # 123.4 -> "123.40"

		formulaire='x'*8000
		libcybermut.CreerFormulaireCM(
		  self.url_banque, 
		  self.version, 
		  self.getKeyFullPath(self.key_name),
		  "%s%s"%(montant,devise),
		  reference,
		  texte_libre,
		  self.url_retour,
		  self.url_retour_ok,
		  self.url_retour_err,
		  isoLang2CybermutLang(langue),
		  self.code_societe,
		  texte_bouton, 
		  
		  formulaire)
		  
		return string.split(formulaire,'\0')[0]
		
	security.declarePublic('testMAC')
	def testMAC(self, MAC, montant, date, reference, texte_libre, code_retour ):
		"""This function validates a call from Cybermut - known as CGI2"""
		result=libcybermut.TestMAC(
		  MAC, 
		  self.version, 
		  self.getKeyFullPath(self.key_name),
		  date, 
		  montant,
		  reference,
		  texte_libre,
		  code_retour)
		return result
		
		
	security.declarePublic('reponseCM')
	def reponseCM(self):
		"""This function prepares the answer for Cybermut server - last step of CGI2"""
		result='x'*8000
		libcybermut.CreerReponseCM('OK', result)
		return string.split(result,'\0')[0]
		
InitializeClass(Cybermut)		
